# Using Relations
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/relations#overview)
  * [Explicit Relations](https://help.sap.com/docs/leanix/ea/relations#explicit-relations)
  * [Parent/Child Relations](https://help.sap.com/docs/leanix/ea/relations#parent/child-relations)
  * [Requires/Required by Relations](https://help.sap.com/docs/leanix/ea/relations#requires/required-by-relations)
  * [Transitive Relations](https://help.sap.com/docs/leanix/ea/relations#transitive-relations)


Learn how to use different types of relations to model dependencies and interactions between fact sheets.
